attach_new_metadata

Function attach_new_metadata 

pub fn attach_new_metadata(
    ctx: &Context,
    op: Ptr<Operation>,
    kind: impl Into<String>,
    node: MdNodeAttr,
) -> Result<MdNodeId>
Add node to the metadata table of the module enclosing op, and attach it to op under the LLVM metadata kind kind, replacing any existing attachment for that kind.