pub fn find_metadata_table(
ctx: &Context,
op: Ptr<Operation>,
) -> Option<MdTableAttr>Expand description
Starting at op and walking up its ancestors, find the metadata table
of the enclosing [ModuleOp].
pub fn find_metadata_table(
ctx: &Context,
op: Ptr<Operation>,
) -> Option<MdTableAttr>Starting at op and walking up its ancestors, find the metadata table
of the enclosing [ModuleOp].