pub fn set_attachments(
ctx: &Context,
op: Ptr<Operation>,
attachments: MdAttachmentsAttr,
)Expand description
Attach attachments to op, replacing whatever was attached to it.
pub fn set_attachments(
ctx: &Context,
op: Ptr<Operation>,
attachments: MdAttachmentsAttr,
)Attach attachments to op, replacing whatever was attached to it.