verify_metadata

Function verify_metadata 

pub fn verify_metadata(ctx: &Context, module_op: ModuleOp) -> Result<()>
Verify that

  • Every metadata reference in the module rooted at module_op resolves to a node in the module’s metadata table
  • Every constant that a metadata node holds verifies and refers only to symbols of the module.