pub struct MdTableAttr(/* private fields */);Expand description
The module level table of metadata node definitions. A node is referred to, from anywhere in the module, by its index in this table.
Printed as [#0 = !{...}, #1 = distinct !{...}].
Implementations
Sourceimpl MdTableAttr
impl MdTableAttr
Sourcepub fn push(&mut self, node: MdNodeAttr) -> MdNodeId
pub fn push(&mut self, node: MdNodeAttr) -> MdNodeId
Add node to the table and get the MdNodeId it can be referred to by.
Sourcepub fn push_uniqued(&mut self, node: MdNodeAttr) -> MdNodeId
pub fn push_uniqued(&mut self, node: MdNodeAttr) -> MdNodeId
Add node to the table, unless it is a non-distinct node that is structurally
equal to one already in the table, and get the MdNodeId to refer to it by.
Sourcepub fn reserve(&mut self) -> MdNodeId
pub fn reserve(&mut self) -> MdNodeId
Reserve an id for a node whose operands aren’t known yet, so that the node (or a node it refers to) can refer back to it. Must be followed by Self::set for the same id.
Sourcepub fn set(&mut self, id: MdNodeId, node: MdNodeAttr)
pub fn set(&mut self, id: MdNodeId, node: MdNodeAttr)
Set the node at id, which must already be in the table.
Sourcepub fn get(&self, id: MdNodeId) -> Option<&MdNodeAttr>
pub fn get(&self, id: MdNodeId) -> Option<&MdNodeAttr>
The node at id, if there is one.
Sourcepub fn iter(&self) -> impl Iterator<Item = (MdNodeId, &MdNodeAttr)>
pub fn iter(&self) -> impl Iterator<Item = (MdNodeId, &MdNodeAttr)>
Iterate over (id, node) pairs.